@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import gtk, gnome
+import gtk, gnome, gobject
 import gu
 import inputwidgets
 import widgets
@@ -27,6 +27,7 @@ import os
 import sys
 import signal
 import cfg
+import intervaltest
 
 class Teacher(cfg.ConfigUtils):
     def __init__(self, exname, app, config):
@@ -61,10 +62,10 @@ class Teacher(cfg.ConfigUtils):
                 def remove_timeout(self=self):
                     self.m_timeout_handle = None
                     self.g_view.new_question()
-                self.m_timeout_handle = gtk.timeout_add((self.get_int('seconds_before_new_question')*1000),  remove_timeout)
+                self.m_timeout_handle = gobject.timeout_add((self.get_int('seconds_before_new_question')*1000),  remove_timeout)
     def end_practise(self):
         if self.m_timeout_handle:
-            gtk.timeout_remove(self.m_timeout_handle)
+            gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
         self.q_status = const.QSTATUS_NO
         soundcard.synth.stop()
@@ -95,7 +96,7 @@ class MelodicIntervalTeacher(Teacher):
                      self.get_list('ask_for_intervals_0'))
 
         if self.m_timeout_handle:
-            gtk.timeout_remove(self.m_timeout_handle)
+            gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
@@ -186,7 +187,7 @@ class LessonbasedTeacher(Teacher):
             self.set_string('lessonfile', lessonfile)
         self.__make_sure_existing_lessonfile_is_selected()
         self.parse_lessonfile()
-        if new_file and self.m_P.header.questions_selectable:
+        if new_file and self.m_P and self.m_P.header.questions_selectable:
             self.block_watch('ask_for_names')
             self.set_list('ask_for_names', range(0, len(self.m_P.get_unique_cnames())))
             self.unblock_watch('ask_for_names')
@@ -221,8 +222,9 @@ class LessonbasedTeacher(Teacher):
 """There was an IOError while trying to parse a lesson file. The cause was probably you deleting or renaming a lesson file. Please don't do this while Solfege is running. The program is still a little fragile. 
 
 You really should reastart the program now.""")
-        if self.m_P.header.musicformat == "cmdline":
-            run = self.m_app.m_ui.dialog_yesno(_("The lessonfile contain potentially dangerous code because the lesson file set the variable \"musicformat\" to \"cmdline\". Run anyway?"))
+        if filter(lambda q: q['music'].m_musictype == 'cmdline',
+                  self.m_P.m_questions):
+            run = self.m_app.m_ui.dialog_yesno(_("The lessonfile contain potentially dangerous code because it run external programs. Run anyway?"))
             if not run:
                 self.m_P = None
     def configure_exercise(self, lessoncollection, lessonfile, config):
@@ -385,7 +387,10 @@ class IntervalGui(Gui):
         self.g_input.show()
         self.m_notenamerange.set_range(self.g_input.m_lowest_tone,
                                        self.g_input.m_highest_tone)
-        self.on_end_practise()
+        if self.m_t.m_tonika:
+            # Don't call on_end_practise if we are starting up the exercise.
+            # This whole thing is a mess.
+            self.on_end_practise()
         self.g_disable_unused_buttons.set_sensitive(self.get_int('inputwidget')==0)
     def setup_key_bindings(self):
         keys = ['minor2', 'major2', 'minor3', 'major3',
@@ -398,6 +403,22 @@ class IntervalGui(Gui):
     def repeat_question(self, *w):
         self.m_t.play_question()
         self.g_input.grab_focus_first_sensitive_button()
+    def show_test_statistics(self, action):
+        if self.g_test_stat_dlg:
+            self.g_test_stat_dlg.destroy()
+            self.g_test_stat_dlg = None
+        t = intervaltest.Test(self.m_t.m_exname)
+        self.g_test_stat_dlg = intervaltest.TestStatisticsDialog(self, _("Test statistics"), t.get_total_results())
+        self.g_test_stat_dlg.show_all()
+        self.g_test_stat_dlg.connect('delete-event', self.destroy_test_stat_dlg)
+    def destroy_test_stat_dlg(self, *ignore):
+        """
+        The self.g_test_stat_dlg is used both for the dialog showing
+        the test statistics and the test results.
+        """
+        assert self.g_test_stat_dlg
+        self.g_test_stat_dlg.destroy()
+        self.g_test_stat_dlg = None
 
 
 class LessonbasedGui(Gui):
@@ -416,8 +437,7 @@ class LessonbasedGui(Gui):
         label.show()
         hbox.pack_start(label, False)
         hbox.set_spacing(6)
-        self.g_random_transpose = gtk.Entry()
-        self.g_random_transpose.set_editable(False)
+        self.g_random_transpose = gtk.Label()
         self.g_random_transpose.show()
         hbox.pack_start(self.g_random_transpose)
 
