@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,18 +15,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import os
-
 MAJOR_VERSION = 2
-MINOR_VERSION = 3
-PATCH_LEVEL = 1
+MINOR_VERSION = 5
+PATCH_LEVEL = 0
 VERSION_STRING = '%s.%s.%s' % (MAJOR_VERSION, MINOR_VERSION, PATCH_LEVEL)
-if "yes" == "yes":
-    WITH_GNOME = 1
-else:
-    WITH_GNOME = 0
-WITH_GTKHTML = "yes" == 'yes'
-prefix = "/usr/local"
-datadir = os.path.join(prefix, "share", "solfege", VERSION_STRING)
 HAVE_LINUX_AWE_VOICE_H = "yes" == "yes"
 ENABLE_TUNER = "no" == "yes"
